@@ -2,5 +2,6 @@ from captcha.fields import ReCaptchaField
 
 from registration.forms import RegistrationForm
 
+
 class RegistrationFormCaptcha(RegistrationForm):
-    captcha = ReCaptchaField(attrs={'options': {'theme': 'white'}})
+    captcha = ReCaptchaField(attrs={'theme': 'white'})
